@@ -40,31 +40,16 @@
 static char write_buf[BUFSIZ];
 static char read_buf[BUFSIZ];
 
-static struct __file_posix __stdin = {
-	.cfile = {
-		.file = FDEV_SETUP_STREAM(NULL, __posix_getc, NULL, __SRD | __SCLOSE),
-		.close = __posix_close
-	},
-	.fd = 0,
-	.read_buf = read_buf
-};
+static struct __file_bufio __stdin = FDEV_SETUP_POSIX(0, read_buf, BUFSIZ, __SRD, 0);
+static struct __file_bufio __stdout = FDEV_SETUP_POSIX(1, write_buf, BUFSIZ, __SWR, __BLBF);
 
-static struct __file_posix __stdout = {
-	.cfile = {
-		.file = FDEV_SETUP_STREAM(__posix_putc, NULL, __posix_flush, __SWR | __SCLOSE),
-		.close = __posix_close
-	},
-	.fd = 1,
-	.write_buf = write_buf
-};
-
-FILE *const __posix_stdin = &__stdin.cfile.file;
-FILE *const __posix_stdout = &__stdout.cfile.file;
+FILE *const __posix_stdin = &__stdin.xfile.cfile.file;
+FILE *const __posix_stdout = &__stdout.xfile.cfile.file;
 
 #ifdef __strong_reference
 __strong_reference(__posix_stdout, __posix_stderr);
 #else
-FILE *const __posix_stderr = &__stdout.cfile.file;
+FILE *const __posix_stderr = &__stdout.xfile.cfile.file;
 #endif
 
 __weak_reference(__posix_stdin,stdin);
