@@ -1,9 +1,9 @@
-// +build feather_m4
+//go:build feather_m4
 
 package machine
 
 // used to reset into bootloader
-const RESET_MAGIC_VALUE = 0xf01669ef
+const resetMagicValue = 0xf01669ef
 
 // GPIO Pins
 const (
@@ -56,12 +56,24 @@ const (
 	UART2_RX_PIN = A5
 )
 
+var (
+	UART1 = &sercomUSART5
+	UART2 = &sercomUSART0
+
+	DefaultUART = UART1
+)
+
 // I2C pins
 const (
 	SDA_PIN = D22 // SDA: SERCOM2/PAD[0]
 	SCL_PIN = D21 // SCL: SERCOM2/PAD[1]
 )
 
+// I2C on the Feather M4.
+var (
+	I2C0 = sercomI2CM2
+)
+
 // SPI pins
 const (
 	SPI0_SCK_PIN = D25 // SCK: SERCOM1/PAD[1]
@@ -69,6 +81,9 @@ const (
 	SPI0_SDI_PIN = D23 // SDI: SERCOM1/PAD[2]
 )
 
+// SPI on the Feather M4.
+var SPI0 = sercomSPIM1
+
 // USB CDC identifiers
 const (
 	usb_STRING_PRODUCT      = "Adafruit Feather M4"
